@@ -2,23 +2,9 @@
 #define POLICYKITLISTENER_H
 
 /*  This file is part of the KDE project
-    Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2009 Jaroslav Reznik <jreznik@redhat.com>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <QHash>
@@ -38,7 +24,7 @@ public:
     explicit PolicyKitListener(QObject *parent = nullptr);
     ~PolicyKitListener() override;
 
-public slots:
+public Q_SLOTS:
     void initiateAuthentication(const QString &actionId,
                                 const QString &message,
                                 const QString &iconName,
@@ -71,7 +57,7 @@ private:
     PolkitQt1::Identity m_selectedUser;
     QHash<QString, qulonglong> m_actionsToWID;
 
-private slots:
+private Q_SLOTS:
     void dialogAccepted();
     void dialogCanceled();
     void userSelected(const PolkitQt1::Identity &identity);
